Module: Consyncful

Defined in:
lib/consyncful/tree/concerns/parent.rb,
lib/consyncful/tree.rb,
lib/consyncful/tree/version.rb,
lib/consyncful/tree/concerns/child.rb,
sig/consyncful_tree.rbs

Overview

Parent module is included to parent Consyncful models This module allows the current parent class to lookup its children no matter where they are.

Defined Under Namespace

Modules: Tree

Constant Summary collapse

VERSION =

Returns:

  • (String)